<?php

namespace Drupal\lightbox_media\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\Attribute\FieldFormatter;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\Plugin\Field\FieldFormatter\EntityReferenceEntityFormatter;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Plugin implementation of the 'lightbox_media_container' formatter.
 */
#[FieldFormatter(
  id: 'lightbox_media_container',
  label: new TranslatableMarkup('Rendered entity in a lightbox container'),
  field_types: [
    'entity_reference',
  ],
)]
class LightboxMediaContainerFormatter extends EntityReferenceEntityFormatter {

  /**
   * {@inheritDoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = parent::viewElements($items, $langcode);
    $container_id = $items->getEntity()->id();
    $elements['#prefix'] = '<div data-lightbox-container="' . $container_id . '">';
    $elements['#suffix'] = '</div>';
    return $elements;
  }

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    // Formatter only available for entity types that reference media items.
    $field_storage_definition = $field_definition->getFieldStorageDefinition();
    return ($field_storage_definition->getSetting('target_type') == 'media')
      && $field_storage_definition->isMultiple();
  }

}
