<?php

namespace Drupal\lightbox\Plugin\Field\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;

/**
 *
 */
trait LightboxImageFormatterTrait {

  /**
   * {@inheritdoc}
   */
  public static function defaultSettings() {
    return parent::defaultSettings() + [
      'lightbox_style' => '',
      'lightbox_link_class' => '',
    ];
  }

  /**
   * Adds the lightbox image style information to the summary array.
   *
   * This method retrieves the lightbox image style setting, resolves it against
   * available image styles, and appends a descriptive message to the summary.
   *
   * @param array $summary
   *   A reference to the summary array to which the image style information
   *   will be added.
   */
  abstract protected function addStyleToSummary(array &$summary): void;

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {

    $summary = parent::settingsSummary();

    $this->addStyleToSummary($summary);

    $link_class = $this->getSetting('lightbox_link_class');
    if ($link_class) {
      $summary[] = $this->t('Lightbox link class: @class', ['@class' => $link_class]);
    }

    return $summary;
  }

  /**
   * Adds an image style selector to the form elements.
   *
   * This method populates the provided form elements array with a dropdown
   * allowing users to select an image style. It integrates the available image
   * styles in the system and includes a link to configure image styles if the
   * user has the necessary permissions.
   *
   * @param array &$element
   *   The form elements array to modify. This array will have a new
   *   'image_style' key with the configured selector.
   */
  abstract protected function addImageStyleSelect(array &$element);

  /**
   * {@inheritdoc}
   */
  public function settingsForm(array $form, FormStateInterface $form_state) {

    $element = parent::settingsForm($form, $form_state);

    unset($element['image_link']);

    $this->addImageStyleSelect($element);

    $element['lightbox_link_class'] = [
      '#title' => $this->t('Lightbox link class'),
      '#type' => 'textfield',
      '#default_value' => $this->getSetting('lightbox_link_class'),
      '#description' => $this->t('Custom class to add to the lightbox link'),
    ];

    return $element;

  }

}
